@@ -22,6 +22,7 @@
 
 #include "tile.h"
 #include "nameplate-tile.h"
+#include "libslab-utils.h"
 
 G_DEFINE_TYPE (TileTable, tile_table, GTK_TYPE_TABLE)
 
@@ -29,6 +30,7 @@ typedef struct {
 	BookmarkAgent   *agent;
 
 	GList           *tiles;
+	GtkSizeGroup    *icon_size_group;
 
 	GtkBin         **bins;
 	gint             n_bins;
@@ -101,8 +103,6 @@ tile_table_new (BookmarkAgent *agent, gint limit, gint n_cols,
 	priv->create_item_func = uti_func;
 	priv->item_func_data   = data_uti;
 
-	tile_table_reload (TILE_TABLE (this));
-
 	g_signal_connect (
 		G_OBJECT (priv->agent), "notify::" BOOKMARK_AGENT_ITEMS_PROP,
 		G_CALLBACK (agent_notify_cb), this);
@@ -120,11 +120,10 @@ tile_table_reload (TileTable *this)
 	GtkWidget     *tile;
 	gint           n_tiles;
 
-	GtkSizeGroup *icon_size_group;
-
 	GList *node;
 	gint   i;
 
+	libslab_checkpoint ("tile_table_reload(): start reloading");
 
 	g_object_get (G_OBJECT (priv->agent), BOOKMARK_AGENT_ITEMS_PROP, & items, NULL);
 
@@ -144,7 +143,8 @@ tile_table_reload (TileTable *this)
 
 	priv->tiles = NULL;
 
-	icon_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	if (!priv->icon_size_group)
+		priv->icon_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 	for (node = tiles; node; node = node->next) {
 		tile = GTK_WIDGET (node->data);
@@ -161,7 +161,7 @@ tile_table_reload (TileTable *this)
 		priv->tiles = g_list_append (priv->tiles, tile);
 
 		if (IS_NAMEPLATE_TILE (tile))
-			gtk_size_group_add_widget (icon_size_group, NAMEPLATE_TILE (tile)->image);
+			gtk_size_group_add_widget (priv->icon_size_group, NAMEPLATE_TILE (tile)->image);
 	}
 
 	g_list_free (tiles);
@@ -169,6 +169,8 @@ tile_table_reload (TileTable *this)
 	update_bins (this, priv->tiles);
 
 	g_object_notify (G_OBJECT (this), TILE_TABLE_TILES_PROP);
+
+	libslab_checkpoint ("tile_table_reload(): end reloading");
 }
 
 void
@@ -341,6 +343,9 @@ finalize (GObject *g_obj)
 {
 	TileTablePrivate *priv = PRIVATE (g_obj);
 
+	if (priv->icon_size_group)
+		g_object_unref (priv->icon_size_group);
+
 	g_free (priv->bins);
 
 	G_OBJECT_CLASS (tile_table_parent_class)->finalize (g_obj);
